/*
 * nciddhangup.h - This file is part of ncidd.
 *
 * Copyright (c) 2005-2019
 * by John L. Chmielewski <jlc@users.sourceforge.net>
 *
 * ncidd is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * ncidd is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with ncidd.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _NCIDDHANGUP_H
#define _NCIDDHANGUP_H

#include <sys/types.h>
#include <regex.h>
#include <pcre.h>   /* Perl regular expressions */


#ifndef BLACKLIST
#define BLACKLIST   "/etc/ncid/ncidd.blacklist"
#endif

#ifndef WHITELIST
#define WHITELIST   "/etc/ncid/ncidd.whitelist"
#endif

#define NOECHO      "ATE0"
#define PICKUP      "ATH1"
#define HANGUP      "ATH0"
#define DATAMODE    "AT+FCLASS=0"

#define FAXANS      "ATA"
#define FAXMODE     "AT+FCLASS=1"
#define FAXDELAY    10   /* seconds */

#define VOICEMODE   "AT+FCLASS=8"
#define SPKRVOL     "AT+VGT=128"

/*
 * Some chipsets take 1 argument, some 2 arguments and some 4 arguments
 * for the voice data formats shown with AT+VSM=?
 * each () indicates an additional argument
 * 4 arguments can always be given, modems seem to ignore extra arguments
 */
#define XPRESS      "AT+VSM=130" // 130,"UNSIGNED PCM",8,0,8000,0,0

#define ANSCALL     "AT+VLS=1"
#define VOICEXFR    "AT+VTX"
#define DLEETX      "\x10\x03"
#define VOICETRY    300 /* number of times to try DLEETX (30 seconds max) */
#define VOICEDELAY  2   /* delay before hangup in seconds */

#define GETOK       "AT"
#define HANGUPTRY   6   /* number of times to try to hangup (0.6 seconds max) */
#define HANGUPDELAY 2   /* delay before hangup in seconds */

#define ENTRYSIZE   180 /* maximum size of a list entry */

typedef struct list
{
    char entry[ENTRYSIZE];	/* a caller name or number */
    char newname[CIDSIZE];	/* the #= substitute name */
    struct list *next;
    struct abwstr * ncidreg;	/* the ncid expression caller */
    regex_t * preg;		/* the regex caller */
    pcre * pcreg;		/* the pcre caller */
}list_t;

extern const char * blacklist;
extern const char * whitelist;
extern const char * listname;
extern int regex;
extern const char * audiofmt;
extern int pickup;
extern struct list *blkHead, *blkCurrent, *whtHead, *whtCurrent,
                   *listHead, *listCurrent;

int doList(const char * filename, list_t **listHead, list_t **listCurrent);
int hangupCall_offhook(int mode);
int hangupCall(int mode, const char * recording);
int onBlackWhite (const char * namep, const char * nmbrp);
int checkWhitelist(const char * namep, const char * nmbrp);
int checkBlacklist(const char * namep, const char * nmbrp);

void rmEntries(list_t **listHead, list_t **listCurrent);

#endif /* nciddhangup.h */
